@@ -12,12 +12,27 @@ class Channel:
     """SkyQ Channel Class."""
 
     channelno: str = field(
-        init=True, repr=True, compare=True,
+        init=True,
+        repr=True,
+        compare=True,
     )
     channelname: str = field(
-        init=True, repr=True, compare=False,
+        init=True,
+        repr=True,
+        compare=False,
+    )
+    channelsid: str = field(
+        init=True,
+        repr=True,
+        compare=False,
+    )
+    channelimageurl: str = field(
+        init=True,
+        repr=True,
+        compare=False,
     )
     channeltype: str = None
+    channelnoint: int = None
     sf: str = None
 
     def __post_init__(self):
@@ -26,6 +41,7 @@ class Channel:
             self.channeltype = AUDIO
         else:
             self.channeltype = VIDEO
+        self.channelnoint = int(self.channelno)
 
     def __hash__(self):
         """Calculate the hash of this object."""
