@@ -14,7 +14,8 @@ from .classes.channelepg import ChannelEPG
 from .classes.channellist import ChannelList
 from .classes.device import Device
 from .classes.media import Media
-from .classes.programme import Programme, RecordedProgramme
+from .classes.programme import Programme
+from .classes.recordings import Recordings
 from .const import (
     APP_EPG,
     APP_STATUS_VISIBLE,
@@ -29,6 +30,7 @@ from .const import (
     REST_PATH_DEVICEINFO,
     REST_PATH_SYSTEMINFO,
     REST_RECORDING_DETAILS,
+    REST_RECORDINGS_LIST,
     SKY_STATE_NOMEDIA,
     SKY_STATE_OFF,
     SKY_STATE_ON,
@@ -195,7 +197,7 @@ class SkyQRemote:
 
             for n in range(days):
                 programmesData = self._remoteCountry.getEpgData(
-                    sid, channelNo, epgDate + timedelta(days=n)
+                    sid, channelNo, channelName, epgDate + timedelta(days=n)
                 )
                 if len(programmesData) > 0:
                     programmes = programmes.union(programmesData)
@@ -281,17 +283,19 @@ class SkyQRemote:
             _LOGGER.exception(f"X0010 - Error occurred: {self._host} : {sid} : {err}")
             return None
 
+    def getRecordings(self):
+        """Get the list of available Recordings."""
+        resp = self._deviceAccess.http_json(self._jsonport, REST_RECORDINGS_LIST)
+        recData = resp["pvrItems"]
+        recordings = set()
+        for recording in recData:
+            if recording["status"] == "RECORDED":
+                recordings.add(self._buildRecording(recording))
+
+        return Recordings(recordings)
+
     def getRecording(self, pvrId):
         """Get the recording details."""
-        season = None
-        episode = None
-        starttime = None
-        endtime = None
-        programmeuuid = None
-        channel = None
-        imageUrl = None
-        title = None
-
         if self._lastPvrId == pvrId:
             return self._recordedProgramme
         self._lastPvrId = pvrId
@@ -305,6 +309,19 @@ class SkyQRemote:
 
         recording = resp["details"]
 
+        self._recordedProgramme = self._buildRecording(recording)
+        return self._recordedProgramme
+
+    def _buildRecording(self, recording):
+        season = None
+        episode = None
+        starttime = None
+        endtime = None
+        programmeuuid = None
+        channel = None
+        imageUrl = None
+        title = None
+
         channel = recording["cn"]
         title = recording["t"]
         if "seasonnumber" in recording and "episodenumber" in recording:
@@ -325,12 +342,10 @@ class SkyQRemote:
         else:
             endtime = starttime
 
-        self._recordedProgramme = RecordedProgramme(
+        return Programme(
             programmeuuid, starttime, endtime, title, season, episode, imageUrl, channel
         )
 
-        return self._recordedProgramme
-
     def getDeviceInformation(self):
         """Get the device information from the SkyQ box."""
         deviceInfo = self._retrieveInformation(REST_PATH_DEVICEINFO)
